==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-admin/lxqt-admin-user/lxqt-admin-user_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../../../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation type="unfinished">Postavke grupe</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation type="unfinished">Ime grupe:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="37"/>
        <source>Group ID:</source>
        <translation type="unfinished">ID grupe</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="44"/>
        <source>Users belong to this group:</source>
        <translation type="unfinished">Korisnici koji pripadaju ovoj grupi</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="86"/>
        <location filename="../../../groupdialog.cpp" line="95"/>
        <location filename="../../../groupdialog.cpp" line="100"/>
        <source>Error</source>
        <translation type="unfinished">Greška</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="86"/>
        <source>The group ID is in use.</source>
        <translation type="unfinished">ID grupe je u uporabi.</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="95"/>
        <source>The group name cannot be empty.</source>
        <translation type="unfinished">Ime grupe ne može biti prazno.</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="100"/>
        <source>The group name is in use.</source>
        <translation type="unfinished">Ime grupe je u uporabi.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation type="unfinished">Postavke korisnika i grupe</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="31"/>
        <source>&amp;Users</source>
        <translation type="unfinished">&amp;Korisnici</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="50"/>
        <source>Login Name</source>
        <translation type="unfinished">Ime prijave</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="55"/>
        <source>User ID</source>
        <translation type="unfinished">ID korisnika</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="60"/>
        <source>Full Name</source>
        <translation type="unfinished">Puno ime</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="65"/>
        <source>Group</source>
        <translation type="unfinished">Grupa</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="70"/>
        <source>Home Directory</source>
        <translation type="unfinished">Osobna mapa</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="81"/>
        <source>Show system users (for advanced users only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="89"/>
        <source>&amp;Groups</source>
        <translation type="unfinished">&amp;Grupe</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="102"/>
        <source>Name</source>
        <translation type="unfinished">Ime</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="107"/>
        <source>Group ID</source>
        <translation type="unfinished">ID grupe</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="120"/>
        <source>toolBar</source>
        <translation type="unfinished">alatna traka</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="147"/>
        <source>Add</source>
        <translation type="unfinished">Dodaj</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="150"/>
        <source>Add new users or groups</source>
        <translation type="unfinished">Dodaj nove korisnike ili grupe</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="160"/>
        <source>Delete</source>
        <translation type="unfinished">Izbriši</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="163"/>
        <source>Delete selected item</source>
        <translation type="unfinished">Izbriši odabranu stavku</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="173"/>
        <source>Properties</source>
        <translation type="unfinished">Svojstva</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="176"/>
        <source>edit properties of the selected item</source>
        <translation type="unfinished">uredi svojstva odabrane stavke</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="186"/>
        <source>Refresh</source>
        <translation type="unfinished">Osvježi</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="189"/>
        <source>Refresh the lists</source>
        <translation type="unfinished">Osvježi liste</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="145"/>
        <source>Error</source>
        <translation type="unfinished">Greška</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="191"/>
        <location filename="../../../mainwindow.cpp" line="204"/>
        <source>Confirm</source>
        <translation type="unfinished">Potvrdi</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="191"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation type="unfinished">Jeste li sigurni da želite izbrisati odabranoga korisnika?</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="204"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation type="unfinished">Jeste li sigurni da želite izbrisati odabranu grupu?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../../../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation type="unfinished">Postavke korisnika</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="24"/>
        <source>General</source>
        <translation type="unfinished">Općenito</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="33"/>
        <source>Full name:</source>
        <translation type="unfinished">Puno ime:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="43"/>
        <source>Login name:</source>
        <translation type="unfinished">Ime prijave:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="53"/>
        <source>Set password:</source>
        <translation type="unfinished">Postavi lozinku:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="77"/>
        <source>User ID:</source>
        <translation type="unfinished">ID korisnika:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="84"/>
        <source>Main group:</source>
        <translation type="unfinished">Glavna grupa:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="99"/>
        <source>Advanced</source>
        <translation type="unfinished">Napredno</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="105"/>
        <source>Login shell:</source>
        <translation type="unfinished">Ljuska prijave:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="122"/>
        <source>Home directory:</source>
        <translation type="unfinished">Osobna mapa:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="67"/>
        <source>Change password:</source>
        <translation type="unfinished">Promjeni lozinku:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="128"/>
        <location filename="../../../userdialog.cpp" line="141"/>
        <location filename="../../../userdialog.cpp" line="146"/>
        <source>Error</source>
        <translation type="unfinished">Greška</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="128"/>
        <source>The user ID is in use.</source>
        <translation type="unfinished">ID korisnika je u uporabi.</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="141"/>
        <source>The user name cannot be empty.</source>
        <translation type="unfinished">Korisničko ime ne može biti prazno.</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="146"/>
        <source>The user name is in use.</source>
        <translation type="unfinished">Korisničko ime je u uoprabi.</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="162"/>
        <source>Confirm</source>
        <translation type="unfinished">Potvrdi</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="162"/>
        <source>Are you sure you want to use an &quot;empty password&quot; for the user?</source>
        <translation type="unfinished">Jeste li sigurni da želite koristiti &quot;praznu lozinku&quot; za korisnika?</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-admin/lxqt-admin-user/lxqt-admin-user_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../../../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation type="unfinished">Postavke grupe</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation type="unfinished">Ime grupe:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation type="unfinished">ID grupe</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation type="unfinished">Korisnici koji pripadaju ovoj grupi</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation type="unfinished">Greška</translation>
    </message>
    <message>
        <source>The group ID is in use.</source>
        <translation type="obsolete">ID grupe je u uporabi.</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation type="unfinished">Ime grupe ne može biti prazno.</translation>
    </message>
    <message>
        <source>The group name is in use.</source>
        <translation type="obsolete">Ime grupe je u uporabi.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation type="unfinished">Postavke korisnika i grupe</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translation type="unfinished">&amp;Korisnici</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="59"/>
        <source>Login Name</source>
        <translation type="unfinished">Ime prijave</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="64"/>
        <source>User ID</source>
        <translation type="unfinished">ID korisnika</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="69"/>
        <source>Full Name</source>
        <translation type="unfinished">Puno ime</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="74"/>
        <source>Group</source>
        <translation type="unfinished">Grupa</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="79"/>
        <source>Home Directory</source>
        <translation type="unfinished">Osobna mapa</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation type="unfinished">&amp;Grupe</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="111"/>
        <source>Name</source>
        <translation type="unfinished">Ime</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="116"/>
        <source>Group ID</source>
        <translation type="unfinished">ID grupe</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="121"/>
        <source>Members</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="134"/>
        <source>toolBar</source>
        <translation type="unfinished">alatna traka</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="161"/>
        <source>Add</source>
        <translation type="unfinished">Dodaj</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="164"/>
        <source>Add new users or groups</source>
        <translation type="unfinished">Dodaj nove korisnike ili grupe</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="173"/>
        <source>Delete</source>
        <translation type="unfinished">Izbriši</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="176"/>
        <source>Delete selected item</source>
        <translation type="unfinished">Izbriši odabranu stavku</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="185"/>
        <source>Properties</source>
        <translation type="unfinished">Svojstva</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="188"/>
        <source>edit properties of the selected item</source>
        <translation type="unfinished">uredi svojstva odabrane stavke</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="197"/>
        <source>Refresh</source>
        <translation type="unfinished">Osvježi</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="200"/>
        <source>Refresh the lists</source>
        <translation type="unfinished">Osvježi liste</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="209"/>
        <source>Change Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="212"/>
        <source>Change password for the selected user or group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="obsolete">Greška</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="174"/>
        <location filename="../../../mainwindow.cpp" line="186"/>
        <location filename="../../../mainwindow.cpp" line="207"/>
        <source>Confirm</source>
        <translation type="unfinished">Potvrdi</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="174"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation type="unfinished">Jeste li sigurni da želite izbrisati odabranoga korisnika?</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="186"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation type="unfinished">Jeste li sigurni da želite izbrisati odabranu grupu?</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="197"/>
        <source>Input the new password for %1:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="207"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../../../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation type="unfinished">Postavke korisnika</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="24"/>
        <source>General</source>
        <translation type="unfinished">Općenito</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation type="unfinished">Puno ime:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation type="unfinished">Ime prijave:</translation>
    </message>
    <message>
        <source>Set password:</source>
        <translation type="obsolete">Postavi lozinku:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation type="unfinished">ID korisnika:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation type="unfinished">Glavna grupa:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation type="unfinished">Napredno</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation type="unfinished">Ljuska prijave:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation type="unfinished">Osobna mapa:</translation>
    </message>
    <message>
        <source>Change password:</source>
        <translation type="obsolete">Promjeni lozinku:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="117"/>
        <source>Error</source>
        <translation type="unfinished">Greška</translation>
    </message>
    <message>
        <source>The user ID is in use.</source>
        <translation type="obsolete">ID korisnika je u uporabi.</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="117"/>
        <source>The user name cannot be empty.</source>
        <translation type="unfinished">Korisničko ime ne može biti prazno.</translation>
    </message>
    <message>
        <source>The user name is in use.</source>
        <translation type="obsolete">Korisničko ime je u uoprabi.</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation type="obsolete">Potvrdi</translation>
    </message>
    <message>
        <source>Are you sure you want to use an &quot;empty password&quot; for the user?</source>
        <translation type="obsolete">Jeste li sigurni da želite koristiti &quot;praznu lozinku&quot; za korisnika?</translation>
    </message>
</context>
<context>
    <name>UserManager</name>
    <message>
        <location filename="../../../usermanager.cpp" line="224"/>
        <source>lxqt-admin-user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../usermanager.cpp" line="225"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
